==> larus_board-0.8.36.tbz: larus_board-0.8.36/lb_private/action.acp_task_edit.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board".
 *
 * "Larus Board" is free software: you can redistribute it and/or modify
 * it under the terms of the modified BSD license.
 *
 * "Larus Board" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You should have received a copy of the modified BSD License
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.BSD>.
 */
  if ( !defined('__XF_INCLUDE') )
  die('File "'.basename(__FILE__).'" cannot be executed directly!');

/**
* @package lbfrontend
*/
class XFAction_acp_task_edit extends XFAction {
protected $success = false;
protected $error = '';
protected $gpc = array();
protected $markgpc = array();
public $version = 0x01;

  /**
  * @param string $a select handler
  * @param array $b input data for asynchronous request
  * @return mixed
  * @since 1.0.0
  */
  public function init($a,$b){
  XFUI::load_lang_res('','acp');
  return $this->$a($b);
  }

  /**
  * @return true
  * @since 1.0.0
  */
  protected function regular(){
  XFUI::html_redirect(-1,XF::link('acp_overview'));
  return true;
  }

  /**
  * fetch vars from asynchronous request
  * @param array $input input stream
  * @return true
  * @since 1.0.0
  */
  protected function ajax($input){
  $id = XF::sanitize_var(XF::ifset($input,'id',''),'str','restrict,length=4-16');
  $active = XF::sanitize_var(XF::ifset($input,'f_active',0),'booli');
  $interval = XF::sanitize_var(XF::ifset($input,'f_interval',3600),'int','range=60-'.(365*86400));
  $this->gpc = array('id'=>$id,'f_active'=>$active,'f_interval'=>$interval);
  $this->markgpc = array('f_name','f_interval');
  return true;
  }

  /**
  * edit a scheduled task
  * @return boolean
  * @since 1.0.0
  */
  public function execute(){
    try {
      if ( !file_exists(XF::vault_query('root_path').'/task.'.$this->gpc['id'].'.php') )
      $this->error = '{:file_not_found}';

      if ( empty($this->error) ){
        if ( !XF::sql_transaction('begin',array('config_task'=>'w')) )
        throw new XFE('unable to begin database transaction');
      XF::sql_query("UPDATE ".XF::tbl('config_task')." SET ct_interval = :interval, ct_active = :active WHERE ct_command = :id",array(
      'id'=>array($this->gpc['id'],'str'),
      'interval'=>array($this->gpc['f_interval'],'int'),
      'active'=>array($this->gpc['f_active'],'str')),__METHOD__,__LINE__);
      XF::logger('info','command',$this->gpc['id'],'now_active',$this->gpc['f_active']);
      XF::sql_transaction('commit');
      $this->success = true;
      }
    } catch ( XFE $E ){ $E->handle(); if ( $E->check_abort() ) return false; }
  return true;
  }

}

  function xfaf_acp_task_edit($input){
  $a = new XFAction_acp_task_edit();
  $a->init('ajax',$input);
    if ( !xfaf_process_data($a->get_GPC(),$a->get_mark_GPC()) )
    return false;
  $a->execute();
    if ( $a->get_success() )
    return xfaf_success(XF::link('acp_task_list'),'{:edit_task_successful}');
    else
    return xfaf_failure($a->get_error());
  }

?>

==> larus_board-0.9.0.tbz: larus_board-0.9.0/lb_private/action.acp_task_edit.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board".
 *
 * "Larus Board" is free software: you can redistribute it and/or modify
 * it under the terms of the modified BSD license.
 *
 * "Larus Board" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You should have received a copy of the modified BSD License
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.BSD>.
 */
  if ( !defined('__XF_INCLUDE') )
  die('File "'.basename(__FILE__).'" cannot be executed directly!');

/**
* @package lbfrontend
*/
class XFAction_acp_task_edit extends XFAction {
const USE_TAN = true;
protected $success = false;
protected $error = '';
protected $gpc = array();
protected $markgpc = array();
public $version = 0x01;

  /**
  * @param string $a select handler
  * @param array $b input data for asynchronous request
  * @return mixed
  * @since 1.0.0
  */
  public function init($a,$b){
  XFUI::load_lang_res('','acp');
  return $this->$a($b);
  }

  /**
  * @return true
  * @since 1.0.0
  */
  protected function regular(){
  XFUI::html_redirect(-1,XF::link('acp_overview'));
  return true;
  }

  /**
  * fetch vars from asynchronous request
  * @param array $input input stream
  * @return true
  * @since 1.0.0
  */
  protected function ajax($input){
  $id = XF::sanitize_var(XF::ifset($input,'id',''),'str','restrict,length=4-16');
  $active = XF::sanitize_var(XF::ifset($input,'f_active',0),'booli');
  $interval = XF::sanitize_var(XF::ifset($input,'f_interval',3600),'int','range=60-'.(365*86400));
  $this->gpc = array('id'=>$id,'f_active'=>$active,'f_interval'=>$interval);
  $this->markgpc = array('f_name','f_interval');
  return true;
  }

  /**
  * edit a scheduled task
  * @return boolean
  * @since 1.0.0
  */
  public function execute(){
    try {
      if ( !file_exists(XF::vault_query('root_path').'/task.'.$this->gpc['id'].'.php') )
      $this->error = '{:file_not_found}';

      if ( empty($this->error) ){
        if ( !XF::sql_transaction('begin',array('config_task'=>'w')) )
        throw new XFE('unable to begin database transaction');
      XF::sql_query("UPDATE ".XF::tbl('config_task')." SET ct_interval = :interval, ct_active = :active WHERE ct_command = :id",array(
      'id'=>array($this->gpc['id'],'str'),
      'interval'=>array($this->gpc['f_interval'],'int'),
      'active'=>array($this->gpc['f_active'],'str')),__METHOD__,__LINE__);
      XF::logger('info','command',$this->gpc['id'],'now_active',$this->gpc['f_active']);
      XF::sql_transaction('commit');
      $this->success = true;
      }
    } catch ( XFE $E ){ $E->handle(); if ( $E->check_abort() ) return false; }
  return true;
  }

}

  function xfaf_acp_task_edit($input){
  $a = new XFAction_acp_task_edit();
  $a->init('ajax',$input);
    if ( !xfaf_process_data($a->get_GPC(),$a->get_mark_GPC()) )
    return false;
  $a->execute();
    if ( $a->get_success() )
    return xfaf_success(XF::link('acp_task_list','',false),'{:edit_task_successful}');
    else
    return xfaf_failure($a->get_error());
  }

?>
